'use strict';

var _rollupPluginBabelHelpers = require('../_rollupPluginBabelHelpers-00d81fcb.js');
var iconHelpers = require('@rocketsoftware/icon-helpers');

var virtual_AudioConsole16 = {
  name: 'AudioConsole16',
  functional: true,
  // We use title as the prop name as it is not a valid attribute for an SVG
  // HTML element
  props: ['title'],
  render: function render(createElement, context) {
    var children = context.children,
        data = context.data,
        listeners = context.listeners,
        props = context.props;
    var attrs = iconHelpers.getAttributes(_rollupPluginBabelHelpers._objectSpread2({
      width: '16',
      height: '16',
      viewBox: '0 0 32 32',
      preserveAspectRatio: 'xMidYMid meet',
      xmlns: 'http://www.w3.org/2000/svg',
      // Special case here, we need to coordinate that we are using title,
      // potentially, to get the right focus attributes
      title: props.title
    }, data.attrs));
    var svgData = {
      attrs: attrs,
      on: listeners
    };

    if (data.staticClass) {
      svgData.class = _rollupPluginBabelHelpers._defineProperty({}, data.staticClass, true);
    }

    if (data.class) {
      svgData.class = svgData.class || {}; // may be no static class

      svgData.class[data.class] = true;
    } // remove style set by getAttributes


    delete svgData.attrs.style; // combine incoming staticStyle, style with default willChange

    svgData.style = _rollupPluginBabelHelpers._objectSpread2({
      willChange: 'transform'
    }, data.staticStyle, {}, data.style);
    return createElement('svg', svgData, [props.title && createElement('title', null, props.title), createElement('path', {
      attrs: {
        "d": "M30,20H29V2H27V20H26a2.0027,2.0027,0,0,0-2,2v2a2.0027,2.0027,0,0,0,2,2h1v4h2V26h1a2.0027,2.0027,0,0,0,2-2V22A2.0027,2.0027,0,0,0,30,20Zm0,4H26V22h4Z",
        "transform": "translate(0 .005)"
      }
    }), createElement('path', {
      attrs: {
        "d": "M22,14H21V2H19V14H18a2.002,2.002,0,0,0-2,2v2a2.0023,2.0023,0,0,0,2,2h1V30h2V20h1a2.0027,2.0027,0,0,0,2-2V16A2.0023,2.0023,0,0,0,22,14Zm0,4H18V16h4Z",
        "transform": "translate(0 .005)"
      }
    }), createElement('path', {
      attrs: {
        "d": "M14,7H13V2H11V7H10A2.002,2.002,0,0,0,8,9v2a2.002,2.002,0,0,0,2,2h1V30h2V13h1a2.002,2.002,0,0,0,2-2V9A2.002,2.002,0,0,0,14,7Zm0,4H10V9h4Z",
        "transform": "translate(0 .005)"
      }
    }), createElement('path', {
      attrs: {
        "d": "M6,21H5V2H3V21H2a2.0023,2.0023,0,0,0-2,2v2a2.0023,2.0023,0,0,0,2,2H3v3H5V27H6a2.0023,2.0023,0,0,0,2-2V23A2.0023,2.0023,0,0,0,6,21Zm0,4H2V23l4-.001Z",
        "transform": "translate(0 .005)"
      }
    }), children]);
  }
};

module.exports = virtual_AudioConsole16;
